@@ -17,7 +17,6 @@ from . import dots
 from . import dvm
 from . import games
 from . import learn
-from . import namespace
 from . import sam
 from . import store
 from . import tools
@@ -29,7 +28,6 @@ from .dots import *
 from .dvm import *
 from .games import *
 from .learn import *
-from .namespace import *
 from .sam import *
 from .store import *
 from .tools import *
@@ -37,4 +35,4 @@ from .uuid_generator import *
 
 __author__ = 'Daniel Bakas Amuchastegui'
 __email__ = 'danielbakas@gmail.com'
-__version__ = '0.0.0.44'
\ No newline at end of file
+__version__ = '0.0.0.45'
\ No newline at end of file
